# FileMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**info** | **str** |  | [optional] 
**is_media_file** | **bool** |  | [optional] 
**md5** | **str** |  | [optional] 
**sha1** | **str** |  | [optional] 
**sha256** | **str** |  | [optional] 
**sha512** | **str** |  | [optional] 
**size** | **int** |  | [optional] 
**ssdeep** | **str** |  | [optional] 
**type** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


